summaryrefslogtreecommitdiff
path: root/src/include/taler_exchange_service.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_exchange_service.h')
-rw-r--r--src/include/taler_exchange_service.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/include/taler_exchange_service.h b/src/include/taler_exchange_service.h
index 1c29e15c1..09eca8ed4 100644
--- a/src/include/taler_exchange_service.h
+++ b/src/include/taler_exchange_service.h
@@ -628,9 +628,9 @@ struct TALER_EXCHANGE_WireAggregateFees
struct TALER_EXCHANGE_WireAccount
{
/**
* payto://-URL of the exchange.
*/
- const char *url;
+ const char *payto_uri;
/**
* Signature of the exchange over the account (was checked by the API).
@@ -639,7 +639,7 @@ struct TALER_EXCHANGE_WireAccount
/**
* Linked list of wire fees the exchange charges for
* accounts of the wire method matching @e url.
*/
const struct TALER_EXCHANGE_WireAggregateFees *fees;
@@ -628,9 +628,9 @@ struct TALER_EXCHANGE_WireAggregateFees
{
/**
- * payto://-URL of the exchange.
+ * payto://-URI of the exchange.
*/
@@ -639,7 +639,7 @@ struct TALER_EXCHANGE_WireAccount
/**
* Linked list of wire fees the exchange charges for
- * accounts of the wire method matching @e url.
+ * accounts of the wire method matching @e payto_uri.
*/
const struct TALER_EXCHANGE_WireAggregateFees *fees;